@@ -183,9 +183,10 @@ def create_label(
         disabled_font_color = "#888888",
         disabled_background_color = "transparent",
         disabled_border_width = 0,
-        disabled_border_color = "#4a4a4a"
+        disabled_border_color = "#4a4a4a",
+        parent = None
 ):
-    label = QLabel(text)
+    label = QLabel(text, parent)
     padding_left_value = padding_left if padding_left is not None else padding
     padding_top_value = padding_top if padding_top is not None else padding
     padding_right_value = padding_right if padding_right is not None else padding
@@ -383,12 +384,12 @@ def create_text_box(
             font_color = font_color,
             font_family = font_family,
             font_size = font_size,
-            background_color = background_color,
-            hover_background_color = hover_background_color,
-            disabled_background_color = disabled_background_color,
+            background_color = "transparent",
+            hover_background_color = "transparent",
+            disabled_background_color = "transparent",
+            parent = text_box
         )
         placeholder_label.setTextFormat(Qt.TextFormat.RichText)
-        placeholder_label.setAttribute(Qt.WidgetAttribute.WA_TransparentForMouseEvents)
         placeholder_label.move(padding_left_value + 2, padding_top_value + 2)
         placeholder_label.show()
 
